Crate bevy_dev_tools

Crate bevy_dev_tools 

This crate provides additional utilities for the Bevy game engine, focused on improving developer experience.

Modules

ci_testingbevy_ci_testing
Utilities for testing in CI environments.
diagnostics_overlay
Overlay showing diagnostics
fps_overlay
Module containing logic for FPS overlay.
frame_time_graph
Module containing logic for the frame time graph
infinite_grid
This module implements an infinite grid with colored major axis.
picking_debug
Text and on-screen debugging tools
render_debug
Renderer debugging overlay
schedule_dataschedule_data
Tools for extracting schedule data from an app, and interpreting that data for use with visualization tools (for example).
states
Tools for debugging states.

Structs

CameraMovement
Move the camera to the given position
EasyCameraMovementPlugin
Plugin to move the camera smoothly according to the current time
EasyScreenRecordPluginscreenrecording
Add this plugin to your app to enable easy screen recording.
EasyScreenRecordSystemsscreenrecording
The Update systems that the EasyScreenRecordPlugin runs to start and stop recording on user command and to send frames to the thread that manages video file creation. These systems manipulate virtual time in order to capture frames for video.
EasyScreenshotPlugin
Add this plugin to your app to enable easy screenshotting.

Enums

Presetscreenrecording and non-Windows
An encoder preset, which should handle most of the configuration.
RecordScreenscreenrecording
Controls screen recording
ScreenshotFormat
File format the screenshot will be saved in
Tunescreenrecording and non-Windows
Tunes the encoder for a certain kind of video.