Module diagnostics_overlay

Module diagnostics_overlay 

Overlay showing diagnostics

The window can be created using the DiagnosticsOverlay component

Structs

DiagnosticsOverlay
Diagnostics overlay displays on a draggable and collapsible window statistics stored on the DiagnosticsStore. Spawning an entity with this component will create the window for you. Some presets are also provided.
DiagnosticsOverlayItem
An item to be displayed on the overlay.
DiagnosticsOverlayPlane
Marker for the UI root that will hold all of the DiagnosticsOverlay entities.
DiagnosticsOverlayPlugin
Plugin that builds a visual overlay to present diagnostics.
DiagnosticsOverlayStyle
Configures the style of diagnostic overlays

Enums

DiagnosticsOverlayStatistic
The statistic to use when displaying a diagnostic
DiagnosticsOverlaySystems
System set for the systems of the DiagnosticsOverlayPlugin

Constants

INITIAL_DIAGNOSTICS_OVERLAY_PLANE_Z_INDEX
Initial Z-index for the DiagnosticsOverlayPlane