pub struct DebugPickingPlugin;Expand description
Logs events for debugging
“Normal” events are logged at the debug level. “Noisy” events are logged at the trace level.
See Bevy’s LogPlugin and Bevy
Cheatbook: Logging, Console Messages for
details.
Usually, the default level printed is info, so debug and trace messages will not be displayed
even when this plugin is active. You can set RUST_LOG to change this.
You can also change the log filter at runtime in your code. The LogPlugin docs give an example.
Use the DebugPickingMode state resource to control this plugin. Example:
ⓘ
use DebugPickingMode::{Normal, Disabled};
app.insert_resource(DebugPickingMode::Normal)
.add_systems(
PreUpdate,
(|mut mode: ResMut<DebugPickingMode>| {
*mode = match *mode {
DebugPickingMode::Disabled => DebugPickingMode::Normal,
_ => DebugPickingMode::Disabled,
};
})
.distributive_run_if(bevy::input::common_conditions::input_just_pressed(
KeyCode::F3,
)),
)This sets the starting mode of the plugin to DebugPickingMode::Disabled and binds the F3 key
to toggle it.