This crate provides additional utilities for the Bevy game engine, focused on improving developer experience.
Modules
- ci_
testing bevy_ci_testing - Utilities for testing in CI environments.
- diagnostics_
overlay - Overlay showing diagnostics
- fps_
overlay - Module containing logic for FPS overlay.
- frame_
time_ graph - Module containing logic for the frame time graph
- infinite_
grid - This module implements an infinite grid with colored major axis.
- picking_
debug - Text and on-screen debugging tools
- render_
debug - Renderer debugging overlay
- schedule_
data schedule_data - Tools for extracting schedule data from an app, and interpreting that data for use with visualization tools (for example).
- states
- Tools for debugging states.
Structs
- Camera
Movement - Move the camera to the given position
- Easy
Camera Movement Plugin - Plugin to move the camera smoothly according to the current time
- Easy
Screen Record Plugin screenrecording - Add this plugin to your app to enable easy screen recording.
- Easy
Screen Record Systems screenrecording - The
Updatesystems that theEasyScreenRecordPluginruns to start and stop recording on user command and to send frames to the thread that manages video file creation. These systems manipulatevirtualtimein order to capture frames for video. - Easy
Screenshot Plugin - Add this plugin to your app to enable easy screenshotting.
Enums
- Preset
screenrecordingand non-Windows - An encoder preset, which should handle most of the configuration.
- Record
Screen screenrecording - Controls screen recording
- Screenshot
Format - File format the screenshot will be saved in
- Tune
screenrecordingand non-Windows - Tunes the encoder for a certain kind of video.